# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SecondaryIndexArgs', 'SecondaryIndex']

@pulumi.input_type
class SecondaryIndexArgs:
    def __init__(__self__, *,
                 include_base_data: pulumi.Input[bool],
                 index_name: pulumi.Input[str],
                 index_type: pulumi.Input[str],
                 instance_name: pulumi.Input[str],
                 primary_keys: pulumi.Input[Sequence[pulumi.Input[str]]],
                 table_name: pulumi.Input[str],
                 defined_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SecondaryIndex resource.
        :param pulumi.Input[bool] include_base_data: whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        :param pulumi.Input[str] index_name: The index name of the OTS Table. If changed, a new index would be created.
        :param pulumi.Input[str] index_type: The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        :param pulumi.Input[str] instance_name: The name of the OTS instance in which table will located.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] primary_keys: A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[str] table_name: The name of the OTS table. If changed, a new table would be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] defined_columns: A list of defined column for index, referenced from Table's primary keys or predefined columns.
        """
        pulumi.set(__self__, "include_base_data", include_base_data)
        pulumi.set(__self__, "index_name", index_name)
        pulumi.set(__self__, "index_type", index_type)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "primary_keys", primary_keys)
        pulumi.set(__self__, "table_name", table_name)
        if defined_columns is not None:
            pulumi.set(__self__, "defined_columns", defined_columns)

    @property
    @pulumi.getter(name="includeBaseData")
    def include_base_data(self) -> pulumi.Input[bool]:
        """
        whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        """
        return pulumi.get(self, "include_base_data")

    @include_base_data.setter
    def include_base_data(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_base_data", value)

    @property
    @pulumi.getter(name="indexName")
    def index_name(self) -> pulumi.Input[str]:
        """
        The index name of the OTS Table. If changed, a new index would be created.
        """
        return pulumi.get(self, "index_name")

    @index_name.setter
    def index_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "index_name", value)

    @property
    @pulumi.getter(name="indexType")
    def index_type(self) -> pulumi.Input[str]:
        """
        The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        """
        return pulumi.get(self, "index_type")

    @index_type.setter
    def index_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "index_type", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Input[str]:
        """
        The name of the OTS instance in which table will located.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="primaryKeys")
    def primary_keys(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "primary_keys")

    @primary_keys.setter
    def primary_keys(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "primary_keys", value)

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> pulumi.Input[str]:
        """
        The name of the OTS table. If changed, a new table would be created.
        """
        return pulumi.get(self, "table_name")

    @table_name.setter
    def table_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "table_name", value)

    @property
    @pulumi.getter(name="definedColumns")
    def defined_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of defined column for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "defined_columns")

    @defined_columns.setter
    def defined_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "defined_columns", value)


@pulumi.input_type
class _SecondaryIndexState:
    def __init__(__self__, *,
                 defined_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 include_base_data: Optional[pulumi.Input[bool]] = None,
                 index_name: Optional[pulumi.Input[str]] = None,
                 index_type: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 primary_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 table_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecondaryIndex resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] defined_columns: A list of defined column for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[bool] include_base_data: whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        :param pulumi.Input[str] index_name: The index name of the OTS Table. If changed, a new index would be created.
        :param pulumi.Input[str] index_type: The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        :param pulumi.Input[str] instance_name: The name of the OTS instance in which table will located.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] primary_keys: A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[str] table_name: The name of the OTS table. If changed, a new table would be created.
        """
        if defined_columns is not None:
            pulumi.set(__self__, "defined_columns", defined_columns)
        if include_base_data is not None:
            pulumi.set(__self__, "include_base_data", include_base_data)
        if index_name is not None:
            pulumi.set(__self__, "index_name", index_name)
        if index_type is not None:
            pulumi.set(__self__, "index_type", index_type)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if primary_keys is not None:
            pulumi.set(__self__, "primary_keys", primary_keys)
        if table_name is not None:
            pulumi.set(__self__, "table_name", table_name)

    @property
    @pulumi.getter(name="definedColumns")
    def defined_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of defined column for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "defined_columns")

    @defined_columns.setter
    def defined_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "defined_columns", value)

    @property
    @pulumi.getter(name="includeBaseData")
    def include_base_data(self) -> Optional[pulumi.Input[bool]]:
        """
        whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        """
        return pulumi.get(self, "include_base_data")

    @include_base_data.setter
    def include_base_data(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_base_data", value)

    @property
    @pulumi.getter(name="indexName")
    def index_name(self) -> Optional[pulumi.Input[str]]:
        """
        The index name of the OTS Table. If changed, a new index would be created.
        """
        return pulumi.get(self, "index_name")

    @index_name.setter
    def index_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "index_name", value)

    @property
    @pulumi.getter(name="indexType")
    def index_type(self) -> Optional[pulumi.Input[str]]:
        """
        The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        """
        return pulumi.get(self, "index_type")

    @index_type.setter
    def index_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "index_type", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the OTS instance in which table will located.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="primaryKeys")
    def primary_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "primary_keys")

    @primary_keys.setter
    def primary_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "primary_keys", value)

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the OTS table. If changed, a new table would be created.
        """
        return pulumi.get(self, "table_name")

    @table_name.setter
    def table_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table_name", value)


class SecondaryIndex(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defined_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 include_base_data: Optional[pulumi.Input[bool]] = None,
                 index_name: Optional[pulumi.Input[str]] = None,
                 index_type: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 primary_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 table_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides an OTS secondary index resource.

        For information about OTS secondary index and how to use it, see [Secondary index overview](https://www.alibabacloud.com/help/en/tablestore/latest/secondary-index-overview).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_instance = alicloud.ots.Instance("default",
            name=f"{name}-{default['result']}",
            description=name,
            accessed_by="Any",
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_table = alicloud.ots.Table("default",
            instance_name=default_instance.name,
            table_name="tf_example",
            time_to_live=-1,
            max_version=1,
            enable_sse=True,
            sse_key_type="SSE_KMS_SERVICE",
            primary_keys=[
                {
                    "name": "pk1",
                    "type": "Integer",
                },
                {
                    "name": "pk2",
                    "type": "String",
                },
                {
                    "name": "pk3",
                    "type": "Binary",
                },
            ],
            defined_columns=[
                {
                    "name": "col1",
                    "type": "Integer",
                },
                {
                    "name": "col2",
                    "type": "String",
                },
                {
                    "name": "col3",
                    "type": "Binary",
                },
            ])
        default_secondary_index = alicloud.ots.SecondaryIndex("default",
            instance_name=default_instance.name,
            table_name=default_table.table_name,
            index_name="example_index",
            index_type="Global",
            include_base_data=True,
            primary_keys=[
                "pk1",
                "pk2",
                "pk3",
            ],
            defined_columns=[
                "col1",
                "col2",
                "col3",
            ])
        ```

        ## Import

        OTS secondary index can be imported using id, e.g.

        ```sh
        $ pulumi import alicloud:ots/secondaryIndex:SecondaryIndex index1 <instance_name>:<table_name>:<index_name>:<index_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] defined_columns: A list of defined column for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[bool] include_base_data: whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        :param pulumi.Input[str] index_name: The index name of the OTS Table. If changed, a new index would be created.
        :param pulumi.Input[str] index_type: The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        :param pulumi.Input[str] instance_name: The name of the OTS instance in which table will located.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] primary_keys: A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[str] table_name: The name of the OTS table. If changed, a new table would be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecondaryIndexArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an OTS secondary index resource.

        For information about OTS secondary index and how to use it, see [Secondary index overview](https://www.alibabacloud.com/help/en/tablestore/latest/secondary-index-overview).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_instance = alicloud.ots.Instance("default",
            name=f"{name}-{default['result']}",
            description=name,
            accessed_by="Any",
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_table = alicloud.ots.Table("default",
            instance_name=default_instance.name,
            table_name="tf_example",
            time_to_live=-1,
            max_version=1,
            enable_sse=True,
            sse_key_type="SSE_KMS_SERVICE",
            primary_keys=[
                {
                    "name": "pk1",
                    "type": "Integer",
                },
                {
                    "name": "pk2",
                    "type": "String",
                },
                {
                    "name": "pk3",
                    "type": "Binary",
                },
            ],
            defined_columns=[
                {
                    "name": "col1",
                    "type": "Integer",
                },
                {
                    "name": "col2",
                    "type": "String",
                },
                {
                    "name": "col3",
                    "type": "Binary",
                },
            ])
        default_secondary_index = alicloud.ots.SecondaryIndex("default",
            instance_name=default_instance.name,
            table_name=default_table.table_name,
            index_name="example_index",
            index_type="Global",
            include_base_data=True,
            primary_keys=[
                "pk1",
                "pk2",
                "pk3",
            ],
            defined_columns=[
                "col1",
                "col2",
                "col3",
            ])
        ```

        ## Import

        OTS secondary index can be imported using id, e.g.

        ```sh
        $ pulumi import alicloud:ots/secondaryIndex:SecondaryIndex index1 <instance_name>:<table_name>:<index_name>:<index_type>
        ```

        :param str resource_name: The name of the resource.
        :param SecondaryIndexArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecondaryIndexArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defined_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 include_base_data: Optional[pulumi.Input[bool]] = None,
                 index_name: Optional[pulumi.Input[str]] = None,
                 index_type: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 primary_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 table_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecondaryIndexArgs.__new__(SecondaryIndexArgs)

            __props__.__dict__["defined_columns"] = defined_columns
            if include_base_data is None and not opts.urn:
                raise TypeError("Missing required property 'include_base_data'")
            __props__.__dict__["include_base_data"] = include_base_data
            if index_name is None and not opts.urn:
                raise TypeError("Missing required property 'index_name'")
            __props__.__dict__["index_name"] = index_name
            if index_type is None and not opts.urn:
                raise TypeError("Missing required property 'index_type'")
            __props__.__dict__["index_type"] = index_type
            if instance_name is None and not opts.urn:
                raise TypeError("Missing required property 'instance_name'")
            __props__.__dict__["instance_name"] = instance_name
            if primary_keys is None and not opts.urn:
                raise TypeError("Missing required property 'primary_keys'")
            __props__.__dict__["primary_keys"] = primary_keys
            if table_name is None and not opts.urn:
                raise TypeError("Missing required property 'table_name'")
            __props__.__dict__["table_name"] = table_name
        super(SecondaryIndex, __self__).__init__(
            'alicloud:ots/secondaryIndex:SecondaryIndex',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            defined_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            include_base_data: Optional[pulumi.Input[bool]] = None,
            index_name: Optional[pulumi.Input[str]] = None,
            index_type: Optional[pulumi.Input[str]] = None,
            instance_name: Optional[pulumi.Input[str]] = None,
            primary_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            table_name: Optional[pulumi.Input[str]] = None) -> 'SecondaryIndex':
        """
        Get an existing SecondaryIndex resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] defined_columns: A list of defined column for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[bool] include_base_data: whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        :param pulumi.Input[str] index_name: The index name of the OTS Table. If changed, a new index would be created.
        :param pulumi.Input[str] index_type: The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        :param pulumi.Input[str] instance_name: The name of the OTS instance in which table will located.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] primary_keys: A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        :param pulumi.Input[str] table_name: The name of the OTS table. If changed, a new table would be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecondaryIndexState.__new__(_SecondaryIndexState)

        __props__.__dict__["defined_columns"] = defined_columns
        __props__.__dict__["include_base_data"] = include_base_data
        __props__.__dict__["index_name"] = index_name
        __props__.__dict__["index_type"] = index_type
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["primary_keys"] = primary_keys
        __props__.__dict__["table_name"] = table_name
        return SecondaryIndex(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="definedColumns")
    def defined_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of defined column for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "defined_columns")

    @property
    @pulumi.getter(name="includeBaseData")
    def include_base_data(self) -> pulumi.Output[bool]:
        """
        whether the index contains data that already exists in the data table. When include_base_data is set to true, it means that stock data is included.
        """
        return pulumi.get(self, "include_base_data")

    @property
    @pulumi.getter(name="indexName")
    def index_name(self) -> pulumi.Output[str]:
        """
        The index name of the OTS Table. If changed, a new index would be created.
        """
        return pulumi.get(self, "index_name")

    @property
    @pulumi.getter(name="indexType")
    def index_type(self) -> pulumi.Output[str]:
        """
        The index type of the OTS Table. If changed, a new index would be created, only `Global` or `Local` is allowed.
        """
        return pulumi.get(self, "index_type")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[str]:
        """
        The name of the OTS instance in which table will located.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="primaryKeys")
    def primary_keys(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of primary keys for index, referenced from Table's primary keys or predefined columns.
        """
        return pulumi.get(self, "primary_keys")

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> pulumi.Output[str]:
        """
        The name of the OTS table. If changed, a new table would be created.
        """
        return pulumi.get(self, "table_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PeerConnectionAccepterArgs', 'PeerConnectionAccepter']

@pulumi.input_type
class PeerConnectionAccepterArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 force_delete: Optional[pulumi.Input[bool]] = None,
                 peer_connection_accepter_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PeerConnectionAccepter resource.
        :param pulumi.Input[str] instance_id: The ID of the VPC peering connection whose name or description you want to modify.
        :param pulumi.Input[int] bandwidth: The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        :param pulumi.Input[str] description: The new description of the VPC peering connection.
               
               The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[bool] force_delete: Specifies whether to forcefully delete the VPC peering connection. Valid values:
        :param pulumi.Input[str] peer_connection_accepter_name: The new name of the VPC peering connection.
               
               The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[str] resource_group_id: The ID of the new resource group.
               
               > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if peer_connection_accepter_name is not None:
            pulumi.set(__self__, "peer_connection_accepter_name", peer_connection_accepter_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC peering connection whose name or description you want to modify.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The new description of the VPC peering connection.

        The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to forcefully delete the VPC peering connection. Valid values:
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_delete", value)

    @property
    @pulumi.getter(name="peerConnectionAccepterName")
    def peer_connection_accepter_name(self) -> Optional[pulumi.Input[str]]:
        """
        The new name of the VPC peering connection.

        The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "peer_connection_accepter_name")

    @peer_connection_accepter_name.setter
    def peer_connection_accepter_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_connection_accepter_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the new resource group.

        > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)


@pulumi.input_type
class _PeerConnectionAccepterState:
    def __init__(__self__, *,
                 accepting_owner_uid: Optional[pulumi.Input[int]] = None,
                 accepting_region_id: Optional[pulumi.Input[str]] = None,
                 accepting_vpc_id: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 force_delete: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 peer_connection_accepter_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PeerConnectionAccepter resources.
        :param pulumi.Input[int] accepting_owner_uid: The ID of the Alibaba Cloud account (primary account) of the receiving end of the VPC peering connection to be created.-to-peer connection to the VPC account.-account VPC peer-to-peer connection.
        :param pulumi.Input[str] accepting_region_id: The region ID of the recipient of the VPC peering connection to be created.-to-peer connection in the same region, enter the same region ID as the region ID of the initiator.-region VPC peer-to-peer connection, enter a region ID that is different from the region ID of the initiator.
        :param pulumi.Input[str] accepting_vpc_id: The VPC ID of the receiving end of the VPC peer connection.
        :param pulumi.Input[int] bandwidth: The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        :param pulumi.Input[str] create_time: The creation time of the VPC peer connection. Use UTC time in the format' YYYY-MM-DDThh:mm:ssZ '.
        :param pulumi.Input[str] description: The new description of the VPC peering connection.
               
               The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[bool] force_delete: Specifies whether to forcefully delete the VPC peering connection. Valid values:
        :param pulumi.Input[str] instance_id: The ID of the VPC peering connection whose name or description you want to modify.
        :param pulumi.Input[str] peer_connection_accepter_name: The new name of the VPC peering connection.
               
               The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[str] resource_group_id: The ID of the new resource group.
               
               > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] vpc_id: The VPC ID of the initiator of the VPC peering connection.
        """
        if accepting_owner_uid is not None:
            pulumi.set(__self__, "accepting_owner_uid", accepting_owner_uid)
        if accepting_region_id is not None:
            pulumi.set(__self__, "accepting_region_id", accepting_region_id)
        if accepting_vpc_id is not None:
            pulumi.set(__self__, "accepting_vpc_id", accepting_vpc_id)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if peer_connection_accepter_name is not None:
            pulumi.set(__self__, "peer_connection_accepter_name", peer_connection_accepter_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="acceptingOwnerUid")
    def accepting_owner_uid(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Alibaba Cloud account (primary account) of the receiving end of the VPC peering connection to be created.-to-peer connection to the VPC account.-account VPC peer-to-peer connection.
        """
        return pulumi.get(self, "accepting_owner_uid")

    @accepting_owner_uid.setter
    def accepting_owner_uid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "accepting_owner_uid", value)

    @property
    @pulumi.getter(name="acceptingRegionId")
    def accepting_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of the recipient of the VPC peering connection to be created.-to-peer connection in the same region, enter the same region ID as the region ID of the initiator.-region VPC peer-to-peer connection, enter a region ID that is different from the region ID of the initiator.
        """
        return pulumi.get(self, "accepting_region_id")

    @accepting_region_id.setter
    def accepting_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accepting_region_id", value)

    @property
    @pulumi.getter(name="acceptingVpcId")
    def accepting_vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID of the receiving end of the VPC peer connection.
        """
        return pulumi.get(self, "accepting_vpc_id")

    @accepting_vpc_id.setter
    def accepting_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accepting_vpc_id", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the VPC peer connection. Use UTC time in the format' YYYY-MM-DDThh:mm:ssZ '.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The new description of the VPC peering connection.

        The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to forcefully delete the VPC peering connection. Valid values:
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_delete", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC peering connection whose name or description you want to modify.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="peerConnectionAccepterName")
    def peer_connection_accepter_name(self) -> Optional[pulumi.Input[str]]:
        """
        The new name of the VPC peering connection.

        The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "peer_connection_accepter_name")

    @peer_connection_accepter_name.setter
    def peer_connection_accepter_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_connection_accepter_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the new resource group.

        > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID of the initiator of the VPC peering connection.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)


class PeerConnectionAccepter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 force_delete: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 peer_connection_accepter_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Vpc Peer Connection Accepter resource.

        For information about Vpc Peer Connection Accepter and how to use it, see [What is Peer Connection Accepter](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-vpcpeer-2022-01-01-acceptvpcpeerconnection).

        > **NOTE:** Available since v1.196.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        accepting_region = config.get("acceptingRegion")
        if accepting_region is None:
            accepting_region = "cn-beijing"
        another_uid = config.get("anotherUid")
        if another_uid is None:
            another_uid = "xxxx"
        local = alicloud.vpc.Network("local",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        accepting_network = alicloud.vpc.Network("accepting",
            vpc_name=name,
            cidr_block="192.168.0.0/16")
        accepting = alicloud.get_account()
        default = alicloud.vpc.PeerConnection("default",
            peer_connection_name=name,
            vpc_id=local.id,
            accepting_ali_uid=accepting.id,
            accepting_region_id=accepting_region,
            accepting_vpc_id=accepting_network.id,
            description=name)
        default_peer_connection_accepter = alicloud.vpc.PeerConnectionAccepter("default", instance_id=default.id)
        ```

        ## Import

        Vpc Peer Connection Accepter can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/peerConnectionAccepter:PeerConnectionAccepter example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        :param pulumi.Input[str] description: The new description of the VPC peering connection.
               
               The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[bool] force_delete: Specifies whether to forcefully delete the VPC peering connection. Valid values:
        :param pulumi.Input[str] instance_id: The ID of the VPC peering connection whose name or description you want to modify.
        :param pulumi.Input[str] peer_connection_accepter_name: The new name of the VPC peering connection.
               
               The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[str] resource_group_id: The ID of the new resource group.
               
               > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PeerConnectionAccepterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Peer Connection Accepter resource.

        For information about Vpc Peer Connection Accepter and how to use it, see [What is Peer Connection Accepter](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-vpcpeer-2022-01-01-acceptvpcpeerconnection).

        > **NOTE:** Available since v1.196.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        accepting_region = config.get("acceptingRegion")
        if accepting_region is None:
            accepting_region = "cn-beijing"
        another_uid = config.get("anotherUid")
        if another_uid is None:
            another_uid = "xxxx"
        local = alicloud.vpc.Network("local",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        accepting_network = alicloud.vpc.Network("accepting",
            vpc_name=name,
            cidr_block="192.168.0.0/16")
        accepting = alicloud.get_account()
        default = alicloud.vpc.PeerConnection("default",
            peer_connection_name=name,
            vpc_id=local.id,
            accepting_ali_uid=accepting.id,
            accepting_region_id=accepting_region,
            accepting_vpc_id=accepting_network.id,
            description=name)
        default_peer_connection_accepter = alicloud.vpc.PeerConnectionAccepter("default", instance_id=default.id)
        ```

        ## Import

        Vpc Peer Connection Accepter can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/peerConnectionAccepter:PeerConnectionAccepter example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PeerConnectionAccepterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PeerConnectionAccepterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 force_delete: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 peer_connection_accepter_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PeerConnectionAccepterArgs.__new__(PeerConnectionAccepterArgs)

            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["description"] = description
            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["force_delete"] = force_delete
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["peer_connection_accepter_name"] = peer_connection_accepter_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["accepting_owner_uid"] = None
            __props__.__dict__["accepting_region_id"] = None
            __props__.__dict__["accepting_vpc_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["vpc_id"] = None
        super(PeerConnectionAccepter, __self__).__init__(
            'alicloud:vpc/peerConnectionAccepter:PeerConnectionAccepter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accepting_owner_uid: Optional[pulumi.Input[int]] = None,
            accepting_region_id: Optional[pulumi.Input[str]] = None,
            accepting_vpc_id: Optional[pulumi.Input[str]] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            force_delete: Optional[pulumi.Input[bool]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            peer_connection_accepter_name: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None) -> 'PeerConnectionAccepter':
        """
        Get an existing PeerConnectionAccepter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] accepting_owner_uid: The ID of the Alibaba Cloud account (primary account) of the receiving end of the VPC peering connection to be created.-to-peer connection to the VPC account.-account VPC peer-to-peer connection.
        :param pulumi.Input[str] accepting_region_id: The region ID of the recipient of the VPC peering connection to be created.-to-peer connection in the same region, enter the same region ID as the region ID of the initiator.-region VPC peer-to-peer connection, enter a region ID that is different from the region ID of the initiator.
        :param pulumi.Input[str] accepting_vpc_id: The VPC ID of the receiving end of the VPC peer connection.
        :param pulumi.Input[int] bandwidth: The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        :param pulumi.Input[str] create_time: The creation time of the VPC peer connection. Use UTC time in the format' YYYY-MM-DDThh:mm:ssZ '.
        :param pulumi.Input[str] description: The new description of the VPC peering connection.
               
               The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[bool] force_delete: Specifies whether to forcefully delete the VPC peering connection. Valid values:
        :param pulumi.Input[str] instance_id: The ID of the VPC peering connection whose name or description you want to modify.
        :param pulumi.Input[str] peer_connection_accepter_name: The new name of the VPC peering connection.
               
               The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        :param pulumi.Input[str] resource_group_id: The ID of the new resource group.
               
               > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] vpc_id: The VPC ID of the initiator of the VPC peering connection.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PeerConnectionAccepterState.__new__(_PeerConnectionAccepterState)

        __props__.__dict__["accepting_owner_uid"] = accepting_owner_uid
        __props__.__dict__["accepting_region_id"] = accepting_region_id
        __props__.__dict__["accepting_vpc_id"] = accepting_vpc_id
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["peer_connection_accepter_name"] = peer_connection_accepter_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        return PeerConnectionAccepter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acceptingOwnerUid")
    def accepting_owner_uid(self) -> pulumi.Output[int]:
        """
        The ID of the Alibaba Cloud account (primary account) of the receiving end of the VPC peering connection to be created.-to-peer connection to the VPC account.-account VPC peer-to-peer connection.
        """
        return pulumi.get(self, "accepting_owner_uid")

    @property
    @pulumi.getter(name="acceptingRegionId")
    def accepting_region_id(self) -> pulumi.Output[str]:
        """
        The region ID of the recipient of the VPC peering connection to be created.-to-peer connection in the same region, enter the same region ID as the region ID of the initiator.-region VPC peer-to-peer connection, enter a region ID that is different from the region ID of the initiator.
        """
        return pulumi.get(self, "accepting_region_id")

    @property
    @pulumi.getter(name="acceptingVpcId")
    def accepting_vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC ID of the receiving end of the VPC peer connection.
        """
        return pulumi.get(self, "accepting_vpc_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        The new bandwidth of the VPC peering connection. Unit: Mbit/s. The value must be an integer greater than 0.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the VPC peer connection. Use UTC time in the format' YYYY-MM-DDThh:mm:ssZ '.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        The new description of the VPC peering connection.

        The description must be 1 to 256 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to forcefully delete the VPC peering connection. Valid values:
        """
        return pulumi.get(self, "force_delete")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC peering connection whose name or description you want to modify.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="peerConnectionAccepterName")
    def peer_connection_accepter_name(self) -> pulumi.Output[str]:
        """
        The new name of the VPC peering connection.

        The name must be 1 to 128 characters in length, and cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "peer_connection_accepter_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the new resource group.

        > **NOTE:**   You can use resource groups to manage resources within your Alibaba Cloud account by group. This helps you resolve issues such as resource grouping and permission management for your Alibaba Cloud account. For more information, see [What is resource management?](https://www.alibabacloud.com/help/en/doc-detail/94475.html)
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC ID of the initiator of the VPC peering connection.
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VswitchCidrReservationArgs', 'VswitchCidrReservation']

@pulumi.input_type
class VswitchCidrReservationArgs:
    def __init__(__self__, *,
                 vswitch_id: pulumi.Input[str],
                 cidr_reservation_cidr: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_description: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_mask: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_type: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr_reservation_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VswitchCidrReservation resource.
        :param pulumi.Input[str] vswitch_id: The Id of the switch instance.
        :param pulumi.Input[str] cidr_reservation_cidr: Reserved network segment CIdrBlock.
        :param pulumi.Input[str] cidr_reservation_description: The description of the reserved CIDR block.
        :param pulumi.Input[str] cidr_reservation_mask: Reserved segment mask.
        :param pulumi.Input[str] cidr_reservation_type: Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        :param pulumi.Input[str] ip_version: Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        :param pulumi.Input[str] vswitch_cidr_reservation_name: The name of the resource.
        """
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if cidr_reservation_cidr is not None:
            pulumi.set(__self__, "cidr_reservation_cidr", cidr_reservation_cidr)
        if cidr_reservation_description is not None:
            pulumi.set(__self__, "cidr_reservation_description", cidr_reservation_description)
        if cidr_reservation_mask is not None:
            pulumi.set(__self__, "cidr_reservation_mask", cidr_reservation_mask)
        if cidr_reservation_type is not None:
            pulumi.set(__self__, "cidr_reservation_type", cidr_reservation_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if vswitch_cidr_reservation_name is not None:
            pulumi.set(__self__, "vswitch_cidr_reservation_name", vswitch_cidr_reservation_name)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The Id of the switch instance.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="cidrReservationCidr")
    def cidr_reservation_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved network segment CIdrBlock.
        """
        return pulumi.get(self, "cidr_reservation_cidr")

    @cidr_reservation_cidr.setter
    def cidr_reservation_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_cidr", value)

    @property
    @pulumi.getter(name="cidrReservationDescription")
    def cidr_reservation_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the reserved CIDR block.
        """
        return pulumi.get(self, "cidr_reservation_description")

    @cidr_reservation_description.setter
    def cidr_reservation_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_description", value)

    @property
    @pulumi.getter(name="cidrReservationMask")
    def cidr_reservation_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved segment mask.
        """
        return pulumi.get(self, "cidr_reservation_mask")

    @cidr_reservation_mask.setter
    def cidr_reservation_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_mask", value)

    @property
    @pulumi.getter(name="cidrReservationType")
    def cidr_reservation_type(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        """
        return pulumi.get(self, "cidr_reservation_type")

    @cidr_reservation_type.setter
    def cidr_reservation_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="vswitchCidrReservationName")
    def vswitch_cidr_reservation_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "vswitch_cidr_reservation_name")

    @vswitch_cidr_reservation_name.setter
    def vswitch_cidr_reservation_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_cidr_reservation_name", value)


@pulumi.input_type
class _VswitchCidrReservationState:
    def __init__(__self__, *,
                 cidr_reservation_cidr: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_description: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_mask: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_type: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr_reservation_id: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr_reservation_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VswitchCidrReservation resources.
        :param pulumi.Input[str] cidr_reservation_cidr: Reserved network segment CIdrBlock.
        :param pulumi.Input[str] cidr_reservation_description: The description of the reserved CIDR block.
        :param pulumi.Input[str] cidr_reservation_mask: Reserved segment mask.
        :param pulumi.Input[str] cidr_reservation_type: Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ip_version: Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] vpc_id: The id of the vpc instance to which the reserved CIDR block belongs.
        :param pulumi.Input[str] vswitch_cidr_reservation_id: The resource attribute field of the resource ID.
        :param pulumi.Input[str] vswitch_cidr_reservation_name: The name of the resource.
        :param pulumi.Input[str] vswitch_id: The Id of the switch instance.
        """
        if cidr_reservation_cidr is not None:
            pulumi.set(__self__, "cidr_reservation_cidr", cidr_reservation_cidr)
        if cidr_reservation_description is not None:
            pulumi.set(__self__, "cidr_reservation_description", cidr_reservation_description)
        if cidr_reservation_mask is not None:
            pulumi.set(__self__, "cidr_reservation_mask", cidr_reservation_mask)
        if cidr_reservation_type is not None:
            pulumi.set(__self__, "cidr_reservation_type", cidr_reservation_type)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_cidr_reservation_id is not None:
            pulumi.set(__self__, "vswitch_cidr_reservation_id", vswitch_cidr_reservation_id)
        if vswitch_cidr_reservation_name is not None:
            pulumi.set(__self__, "vswitch_cidr_reservation_name", vswitch_cidr_reservation_name)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="cidrReservationCidr")
    def cidr_reservation_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved network segment CIdrBlock.
        """
        return pulumi.get(self, "cidr_reservation_cidr")

    @cidr_reservation_cidr.setter
    def cidr_reservation_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_cidr", value)

    @property
    @pulumi.getter(name="cidrReservationDescription")
    def cidr_reservation_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the reserved CIDR block.
        """
        return pulumi.get(self, "cidr_reservation_description")

    @cidr_reservation_description.setter
    def cidr_reservation_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_description", value)

    @property
    @pulumi.getter(name="cidrReservationMask")
    def cidr_reservation_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved segment mask.
        """
        return pulumi.get(self, "cidr_reservation_mask")

    @cidr_reservation_mask.setter
    def cidr_reservation_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_mask", value)

    @property
    @pulumi.getter(name="cidrReservationType")
    def cidr_reservation_type(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        """
        return pulumi.get(self, "cidr_reservation_type")

    @cidr_reservation_type.setter
    def cidr_reservation_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr_reservation_type", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the vpc instance to which the reserved CIDR block belongs.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchCidrReservationId")
    def vswitch_cidr_reservation_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource attribute field of the resource ID.
        """
        return pulumi.get(self, "vswitch_cidr_reservation_id")

    @vswitch_cidr_reservation_id.setter
    def vswitch_cidr_reservation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_cidr_reservation_id", value)

    @property
    @pulumi.getter(name="vswitchCidrReservationName")
    def vswitch_cidr_reservation_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "vswitch_cidr_reservation_name")

    @vswitch_cidr_reservation_name.setter
    def vswitch_cidr_reservation_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_cidr_reservation_name", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Id of the switch instance.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class VswitchCidrReservation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_reservation_cidr: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_description: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_mask: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_type: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr_reservation_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Vpc Vswitch Cidr Reservation resource. The reserved network segment of the vswitch. This resource type can be used only in ap-southeast region.

        For information about Vpc Vswitch Cidr Reservation and how to use it, see [What is Vswitch Cidr Reservation](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/610154).

        > **NOTE:** Available since v1.205.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_vpc = alicloud.vpc.Network("defaultVpc",
            vpc_name=name,
            cidr_block="10.0.0.0/8")
        default_v_switch = alicloud.vpc.Switch("defaultVSwitch",
            vpc_id=default_vpc.id,
            cidr_block="10.0.0.0/20",
            vswitch_name=f"{name}1",
            zone_id=default.zones[0].id)
        default_vswitch_cidr_reservation = alicloud.vpc.VswitchCidrReservation("default",
            ip_version="IPv4",
            vswitch_id=default_v_switch.id,
            cidr_reservation_description=name,
            cidr_reservation_cidr="10.0.10.0/24",
            vswitch_cidr_reservation_name=name,
            cidr_reservation_type="Prefix")
        ```

        ## Import

        Vpc Vswitch Cidr Reservation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/vswitchCidrReservation:VswitchCidrReservation example <vswitch_id>:<vswitch_cidr_reservation_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_reservation_cidr: Reserved network segment CIdrBlock.
        :param pulumi.Input[str] cidr_reservation_description: The description of the reserved CIDR block.
        :param pulumi.Input[str] cidr_reservation_mask: Reserved segment mask.
        :param pulumi.Input[str] cidr_reservation_type: Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        :param pulumi.Input[str] ip_version: Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        :param pulumi.Input[str] vswitch_cidr_reservation_name: The name of the resource.
        :param pulumi.Input[str] vswitch_id: The Id of the switch instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VswitchCidrReservationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Vswitch Cidr Reservation resource. The reserved network segment of the vswitch. This resource type can be used only in ap-southeast region.

        For information about Vpc Vswitch Cidr Reservation and how to use it, see [What is Vswitch Cidr Reservation](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/610154).

        > **NOTE:** Available since v1.205.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_vpc = alicloud.vpc.Network("defaultVpc",
            vpc_name=name,
            cidr_block="10.0.0.0/8")
        default_v_switch = alicloud.vpc.Switch("defaultVSwitch",
            vpc_id=default_vpc.id,
            cidr_block="10.0.0.0/20",
            vswitch_name=f"{name}1",
            zone_id=default.zones[0].id)
        default_vswitch_cidr_reservation = alicloud.vpc.VswitchCidrReservation("default",
            ip_version="IPv4",
            vswitch_id=default_v_switch.id,
            cidr_reservation_description=name,
            cidr_reservation_cidr="10.0.10.0/24",
            vswitch_cidr_reservation_name=name,
            cidr_reservation_type="Prefix")
        ```

        ## Import

        Vpc Vswitch Cidr Reservation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/vswitchCidrReservation:VswitchCidrReservation example <vswitch_id>:<vswitch_cidr_reservation_id>
        ```

        :param str resource_name: The name of the resource.
        :param VswitchCidrReservationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VswitchCidrReservationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_reservation_cidr: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_description: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_mask: Optional[pulumi.Input[str]] = None,
                 cidr_reservation_type: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 vswitch_cidr_reservation_name: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VswitchCidrReservationArgs.__new__(VswitchCidrReservationArgs)

            __props__.__dict__["cidr_reservation_cidr"] = cidr_reservation_cidr
            __props__.__dict__["cidr_reservation_description"] = cidr_reservation_description
            __props__.__dict__["cidr_reservation_mask"] = cidr_reservation_mask
            __props__.__dict__["cidr_reservation_type"] = cidr_reservation_type
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["vswitch_cidr_reservation_name"] = vswitch_cidr_reservation_name
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["vpc_id"] = None
            __props__.__dict__["vswitch_cidr_reservation_id"] = None
        super(VswitchCidrReservation, __self__).__init__(
            'alicloud:vpc/vswitchCidrReservation:VswitchCidrReservation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr_reservation_cidr: Optional[pulumi.Input[str]] = None,
            cidr_reservation_description: Optional[pulumi.Input[str]] = None,
            cidr_reservation_mask: Optional[pulumi.Input[str]] = None,
            cidr_reservation_type: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            ip_version: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_cidr_reservation_id: Optional[pulumi.Input[str]] = None,
            vswitch_cidr_reservation_name: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'VswitchCidrReservation':
        """
        Get an existing VswitchCidrReservation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_reservation_cidr: Reserved network segment CIdrBlock.
        :param pulumi.Input[str] cidr_reservation_description: The description of the reserved CIDR block.
        :param pulumi.Input[str] cidr_reservation_mask: Reserved segment mask.
        :param pulumi.Input[str] cidr_reservation_type: Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] ip_version: Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[str] vpc_id: The id of the vpc instance to which the reserved CIDR block belongs.
        :param pulumi.Input[str] vswitch_cidr_reservation_id: The resource attribute field of the resource ID.
        :param pulumi.Input[str] vswitch_cidr_reservation_name: The name of the resource.
        :param pulumi.Input[str] vswitch_id: The Id of the switch instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VswitchCidrReservationState.__new__(_VswitchCidrReservationState)

        __props__.__dict__["cidr_reservation_cidr"] = cidr_reservation_cidr
        __props__.__dict__["cidr_reservation_description"] = cidr_reservation_description
        __props__.__dict__["cidr_reservation_mask"] = cidr_reservation_mask
        __props__.__dict__["cidr_reservation_type"] = cidr_reservation_type
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_cidr_reservation_id"] = vswitch_cidr_reservation_id
        __props__.__dict__["vswitch_cidr_reservation_name"] = vswitch_cidr_reservation_name
        __props__.__dict__["vswitch_id"] = vswitch_id
        return VswitchCidrReservation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cidrReservationCidr")
    def cidr_reservation_cidr(self) -> pulumi.Output[str]:
        """
        Reserved network segment CIdrBlock.
        """
        return pulumi.get(self, "cidr_reservation_cidr")

    @property
    @pulumi.getter(name="cidrReservationDescription")
    def cidr_reservation_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the reserved CIDR block.
        """
        return pulumi.get(self, "cidr_reservation_description")

    @property
    @pulumi.getter(name="cidrReservationMask")
    def cidr_reservation_mask(self) -> pulumi.Output[Optional[str]]:
        """
        Reserved segment mask.
        """
        return pulumi.get(self, "cidr_reservation_mask")

    @property
    @pulumi.getter(name="cidrReservationType")
    def cidr_reservation_type(self) -> pulumi.Output[str]:
        """
        Reserved CIDR Block Type.Valid values: `Prefix`. Default value: Prefix.
        """
        return pulumi.get(self, "cidr_reservation_type")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[str]:
        """
        Reserved ip version of network segment, valid values: `IPv4`, `IPv6`, default IPv4.
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The id of the vpc instance to which the reserved CIDR block belongs.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchCidrReservationId")
    def vswitch_cidr_reservation_id(self) -> pulumi.Output[str]:
        """
        The resource attribute field of the resource ID.
        """
        return pulumi.get(self, "vswitch_cidr_reservation_id")

    @property
    @pulumi.getter(name="vswitchCidrReservationName")
    def vswitch_cidr_reservation_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "vswitch_cidr_reservation_name")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The Id of the switch instance.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceClassesResult',
    'AwaitableGetInstanceClassesResult',
    'get_instance_classes',
    'get_instance_classes_output',
]

@pulumi.output_type
class GetInstanceClassesResult:
    """
    A collection of values returned by getInstanceClasses.
    """
    def __init__(__self__, architecture=None, classes=None, edition_type=None, engine=None, engine_version=None, id=None, instance_charge_type=None, instance_classes=None, node_type=None, output_file=None, package_type=None, performance_type=None, product_type=None, series_type=None, shard_number=None, sorted_by=None, storage_type=None, zone_id=None):
        if architecture and not isinstance(architecture, str):
            raise TypeError("Expected argument 'architecture' to be a str")
        pulumi.set(__self__, "architecture", architecture)
        if classes and not isinstance(classes, list):
            raise TypeError("Expected argument 'classes' to be a list")
        pulumi.set(__self__, "classes", classes)
        if edition_type and not isinstance(edition_type, str):
            raise TypeError("Expected argument 'edition_type' to be a str")
        pulumi.set(__self__, "edition_type", edition_type)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if engine_version and not isinstance(engine_version, str):
            raise TypeError("Expected argument 'engine_version' to be a str")
        pulumi.set(__self__, "engine_version", engine_version)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_charge_type and not isinstance(instance_charge_type, str):
            raise TypeError("Expected argument 'instance_charge_type' to be a str")
        pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_classes and not isinstance(instance_classes, list):
            raise TypeError("Expected argument 'instance_classes' to be a list")
        pulumi.set(__self__, "instance_classes", instance_classes)
        if node_type and not isinstance(node_type, str):
            raise TypeError("Expected argument 'node_type' to be a str")
        pulumi.set(__self__, "node_type", node_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if package_type and not isinstance(package_type, str):
            raise TypeError("Expected argument 'package_type' to be a str")
        pulumi.set(__self__, "package_type", package_type)
        if performance_type and not isinstance(performance_type, str):
            raise TypeError("Expected argument 'performance_type' to be a str")
        pulumi.set(__self__, "performance_type", performance_type)
        if product_type and not isinstance(product_type, str):
            raise TypeError("Expected argument 'product_type' to be a str")
        pulumi.set(__self__, "product_type", product_type)
        if series_type and not isinstance(series_type, str):
            raise TypeError("Expected argument 'series_type' to be a str")
        pulumi.set(__self__, "series_type", series_type)
        if shard_number and not isinstance(shard_number, int):
            raise TypeError("Expected argument 'shard_number' to be a int")
        pulumi.set(__self__, "shard_number", shard_number)
        if sorted_by and not isinstance(sorted_by, str):
            raise TypeError("Expected argument 'sorted_by' to be a str")
        pulumi.set(__self__, "sorted_by", sorted_by)
        if storage_type and not isinstance(storage_type, str):
            raise TypeError("Expected argument 'storage_type' to be a str")
        pulumi.set(__self__, "storage_type", storage_type)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def architecture(self) -> Optional[str]:
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter
    def classes(self) -> Sequence['outputs.GetInstanceClassesClassResult']:
        """
        A list of KVStore available instance classes when the `sorted_by` is "Price". include:
        """
        return pulumi.get(self, "classes")

    @property
    @pulumi.getter(name="editionType")
    def edition_type(self) -> Optional[str]:
        return pulumi.get(self, "edition_type")

    @property
    @pulumi.getter
    def engine(self) -> Optional[str]:
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> Optional[str]:
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[str]:
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceClasses")
    def instance_classes(self) -> Sequence[str]:
        """
        A list of KVStore available instance classes.
        """
        return pulumi.get(self, "instance_classes")

    @property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[str]:
        return pulumi.get(self, "node_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="packageType")
    @_utilities.deprecated("""The parameter 'package_type' has been deprecated from 1.68.0.""")
    def package_type(self) -> Optional[str]:
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter(name="performanceType")
    @_utilities.deprecated("""The parameter 'performance_type' has been deprecated from 1.68.0.""")
    def performance_type(self) -> Optional[str]:
        return pulumi.get(self, "performance_type")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> Optional[str]:
        return pulumi.get(self, "product_type")

    @property
    @pulumi.getter(name="seriesType")
    def series_type(self) -> Optional[str]:
        return pulumi.get(self, "series_type")

    @property
    @pulumi.getter(name="shardNumber")
    def shard_number(self) -> Optional[int]:
        return pulumi.get(self, "shard_number")

    @property
    @pulumi.getter(name="sortedBy")
    def sorted_by(self) -> Optional[str]:
        return pulumi.get(self, "sorted_by")

    @property
    @pulumi.getter(name="storageType")
    @_utilities.deprecated("""The parameter 'storage_type' has been deprecated from 1.68.0.""")
    def storage_type(self) -> Optional[str]:
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        return pulumi.get(self, "zone_id")


class AwaitableGetInstanceClassesResult(GetInstanceClassesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceClassesResult(
            architecture=self.architecture,
            classes=self.classes,
            edition_type=self.edition_type,
            engine=self.engine,
            engine_version=self.engine_version,
            id=self.id,
            instance_charge_type=self.instance_charge_type,
            instance_classes=self.instance_classes,
            node_type=self.node_type,
            output_file=self.output_file,
            package_type=self.package_type,
            performance_type=self.performance_type,
            product_type=self.product_type,
            series_type=self.series_type,
            shard_number=self.shard_number,
            sorted_by=self.sorted_by,
            storage_type=self.storage_type,
            zone_id=self.zone_id)


def get_instance_classes(architecture: Optional[str] = None,
                         edition_type: Optional[str] = None,
                         engine: Optional[str] = None,
                         engine_version: Optional[str] = None,
                         instance_charge_type: Optional[str] = None,
                         node_type: Optional[str] = None,
                         output_file: Optional[str] = None,
                         package_type: Optional[str] = None,
                         performance_type: Optional[str] = None,
                         product_type: Optional[str] = None,
                         series_type: Optional[str] = None,
                         shard_number: Optional[int] = None,
                         sorted_by: Optional[str] = None,
                         storage_type: Optional[str] = None,
                         zone_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceClassesResult:
    """
    This data source provides the KVStore instance classes resource available info of Alibaba Cloud.

    > **NOTE:** Available since v1.49.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    resources = alicloud.get_zones(available_resource_creation="KVStore")
    resources_get_instance_classes = alicloud.kvstore.get_instance_classes(zone_id=resources.zones[0].id,
        instance_charge_type="PrePaid",
        engine="Redis",
        engine_version="5.0",
        output_file="./classes.txt")
    pulumi.export("firstKvstoreInstanceClass", resources_get_instance_classes.instance_classes)
    ```


    :param str architecture: The KVStore instance system architecture required by the user. Valid values: `standard`, `cluster` and `rwsplit`.
    :param str edition_type: The KVStore instance edition type required by the user. Valid values: `Community` and `Enterprise`.
    :param str engine: Database type. Options are `Redis`, `Memcache`. Default to `Redis`.
    :param str engine_version: Database version required by the user. Value options of Redis can refer to the latest docs [detail info](https://www.alibabacloud.com/help/doc-detail/60873.htm) `EngineVersion`. Value of Memcache should be empty.
    :param str instance_charge_type: Filter the results by charge type. Valid values: `PrePaid` and `PostPaid`. Default to `PrePaid`.
    :param str node_type: The KVStore instance node type required by the user. Valid values: `double`, `single`, `readone`, `readthree` and `readfive`.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
    :param str package_type: It has been deprecated from 1.68.0.
    :param str performance_type: It has been deprecated from 1.68.0.
    :param str series_type: The KVStore instance series type required by the user. Valid values: `enhanced_performance_type` and `hybrid_storage`.
    :param int shard_number: The number of shard.Valid values: `1`, `2`, `4`, `8`, `16`, `32`, `64`, `128`, `256`.
           * product_type - (Optional, Available since 1.130.0) The type of the service. Valid values:
           * Local: an ApsaraDB for Redis instance with a local disk.
           * OnECS: an ApsaraDB for Redis instance with a standard disk. This type is available only on the Alibaba Cloud China site.
    :param str storage_type: It has been deprecated from 1.68.0.
    :param str zone_id: The Zone to launch the KVStore instance.
    """
    __args__ = dict()
    __args__['architecture'] = architecture
    __args__['editionType'] = edition_type
    __args__['engine'] = engine
    __args__['engineVersion'] = engine_version
    __args__['instanceChargeType'] = instance_charge_type
    __args__['nodeType'] = node_type
    __args__['outputFile'] = output_file
    __args__['packageType'] = package_type
    __args__['performanceType'] = performance_type
    __args__['productType'] = product_type
    __args__['seriesType'] = series_type
    __args__['shardNumber'] = shard_number
    __args__['sortedBy'] = sorted_by
    __args__['storageType'] = storage_type
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:kvstore/getInstanceClasses:getInstanceClasses', __args__, opts=opts, typ=GetInstanceClassesResult).value

    return AwaitableGetInstanceClassesResult(
        architecture=pulumi.get(__ret__, 'architecture'),
        classes=pulumi.get(__ret__, 'classes'),
        edition_type=pulumi.get(__ret__, 'edition_type'),
        engine=pulumi.get(__ret__, 'engine'),
        engine_version=pulumi.get(__ret__, 'engine_version'),
        id=pulumi.get(__ret__, 'id'),
        instance_charge_type=pulumi.get(__ret__, 'instance_charge_type'),
        instance_classes=pulumi.get(__ret__, 'instance_classes'),
        node_type=pulumi.get(__ret__, 'node_type'),
        output_file=pulumi.get(__ret__, 'output_file'),
        package_type=pulumi.get(__ret__, 'package_type'),
        performance_type=pulumi.get(__ret__, 'performance_type'),
        product_type=pulumi.get(__ret__, 'product_type'),
        series_type=pulumi.get(__ret__, 'series_type'),
        shard_number=pulumi.get(__ret__, 'shard_number'),
        sorted_by=pulumi.get(__ret__, 'sorted_by'),
        storage_type=pulumi.get(__ret__, 'storage_type'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_instance_classes_output(architecture: Optional[pulumi.Input[Optional[str]]] = None,
                                edition_type: Optional[pulumi.Input[Optional[str]]] = None,
                                engine: Optional[pulumi.Input[Optional[str]]] = None,
                                engine_version: Optional[pulumi.Input[Optional[str]]] = None,
                                instance_charge_type: Optional[pulumi.Input[Optional[str]]] = None,
                                node_type: Optional[pulumi.Input[Optional[str]]] = None,
                                output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                package_type: Optional[pulumi.Input[Optional[str]]] = None,
                                performance_type: Optional[pulumi.Input[Optional[str]]] = None,
                                product_type: Optional[pulumi.Input[Optional[str]]] = None,
                                series_type: Optional[pulumi.Input[Optional[str]]] = None,
                                shard_number: Optional[pulumi.Input[Optional[int]]] = None,
                                sorted_by: Optional[pulumi.Input[Optional[str]]] = None,
                                storage_type: Optional[pulumi.Input[Optional[str]]] = None,
                                zone_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceClassesResult]:
    """
    This data source provides the KVStore instance classes resource available info of Alibaba Cloud.

    > **NOTE:** Available since v1.49.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    resources = alicloud.get_zones(available_resource_creation="KVStore")
    resources_get_instance_classes = alicloud.kvstore.get_instance_classes(zone_id=resources.zones[0].id,
        instance_charge_type="PrePaid",
        engine="Redis",
        engine_version="5.0",
        output_file="./classes.txt")
    pulumi.export("firstKvstoreInstanceClass", resources_get_instance_classes.instance_classes)
    ```


    :param str architecture: The KVStore instance system architecture required by the user. Valid values: `standard`, `cluster` and `rwsplit`.
    :param str edition_type: The KVStore instance edition type required by the user. Valid values: `Community` and `Enterprise`.
    :param str engine: Database type. Options are `Redis`, `Memcache`. Default to `Redis`.
    :param str engine_version: Database version required by the user. Value options of Redis can refer to the latest docs [detail info](https://www.alibabacloud.com/help/doc-detail/60873.htm) `EngineVersion`. Value of Memcache should be empty.
    :param str instance_charge_type: Filter the results by charge type. Valid values: `PrePaid` and `PostPaid`. Default to `PrePaid`.
    :param str node_type: The KVStore instance node type required by the user. Valid values: `double`, `single`, `readone`, `readthree` and `readfive`.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
    :param str package_type: It has been deprecated from 1.68.0.
    :param str performance_type: It has been deprecated from 1.68.0.
    :param str series_type: The KVStore instance series type required by the user. Valid values: `enhanced_performance_type` and `hybrid_storage`.
    :param int shard_number: The number of shard.Valid values: `1`, `2`, `4`, `8`, `16`, `32`, `64`, `128`, `256`.
           * product_type - (Optional, Available since 1.130.0) The type of the service. Valid values:
           * Local: an ApsaraDB for Redis instance with a local disk.
           * OnECS: an ApsaraDB for Redis instance with a standard disk. This type is available only on the Alibaba Cloud China site.
    :param str storage_type: It has been deprecated from 1.68.0.
    :param str zone_id: The Zone to launch the KVStore instance.
    """
    __args__ = dict()
    __args__['architecture'] = architecture
    __args__['editionType'] = edition_type
    __args__['engine'] = engine
    __args__['engineVersion'] = engine_version
    __args__['instanceChargeType'] = instance_charge_type
    __args__['nodeType'] = node_type
    __args__['outputFile'] = output_file
    __args__['packageType'] = package_type
    __args__['performanceType'] = performance_type
    __args__['productType'] = product_type
    __args__['seriesType'] = series_type
    __args__['shardNumber'] = shard_number
    __args__['sortedBy'] = sorted_by
    __args__['storageType'] = storage_type
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:kvstore/getInstanceClasses:getInstanceClasses', __args__, opts=opts, typ=GetInstanceClassesResult)
    return __ret__.apply(lambda __response__: GetInstanceClassesResult(
        architecture=pulumi.get(__response__, 'architecture'),
        classes=pulumi.get(__response__, 'classes'),
        edition_type=pulumi.get(__response__, 'edition_type'),
        engine=pulumi.get(__response__, 'engine'),
        engine_version=pulumi.get(__response__, 'engine_version'),
        id=pulumi.get(__response__, 'id'),
        instance_charge_type=pulumi.get(__response__, 'instance_charge_type'),
        instance_classes=pulumi.get(__response__, 'instance_classes'),
        node_type=pulumi.get(__response__, 'node_type'),
        output_file=pulumi.get(__response__, 'output_file'),
        package_type=pulumi.get(__response__, 'package_type'),
        performance_type=pulumi.get(__response__, 'performance_type'),
        product_type=pulumi.get(__response__, 'product_type'),
        series_type=pulumi.get(__response__, 'series_type'),
        shard_number=pulumi.get(__response__, 'shard_number'),
        sorted_by=pulumi.get(__response__, 'sorted_by'),
        storage_type=pulumi.get(__response__, 'storage_type'),
        zone_id=pulumi.get(__response__, 'zone_id')))
